(function($){

/* ===================================================================
  Google Maps
=================================================================== */
var gmaps = function( el ) {
  var maps = {
    $el: $(el),
    loadScript: function() {
      var script = document.createElement("script");
      script.type = "text/javascript";
      script.src = "http://maps.googleapis.com/maps/api/js?&sensor=true&callback=createMap";
      document.body.appendChild(script);
    },

    addMarker: function(map, opts) {
      var marker, geocoder;

      // Check if maps can use geocoder
      // ------------------------------
      if( opts.address !== '' && typeof opts.address !== 'undefined' ) {
        geocoder = new google.maps.Geocoder();
        geocoder.geocode({
          address: opts.address
        }, function(results, status){
          // Make sure geocoder status is OK
          if( status == "OK" ) {
            map.setCenter( results[0].geometry.location );

            // Set Marker
            marker = new google.maps.Marker({
              position: results[0].geometry.location,
              map: map
            });
          }
        });
      }

      // If can't use geocoder, use lat and lng data
      // -------------------------------------------
      else {
        marker = new google.maps.Marker({
          position: opts.center,
          map: map
        });
      }

      // Add infoWindow
      maps.addInfoWindow(map, marker);
    },

    addInfoWindow: function(map, marker) {
      var infoWindow = new google.maps.InfoWindow();
      if( $('.out-info .address').length > 0 ) {
        infoWindow.setContent( $('.out-info .address').html() );
      }
      infoWindow.open(map, marker);
    },

    createMap: function() {
      $(el).each(function(){
        var $this = $(this),
            lat = $this.data('latitude'),
            lng = $this.data('longitude'),
            addr= $this.data('address'),
            zoom= ($this.data('zoom')) ? $this.data('zoom') : 16,
            mapOptions = {
              zoom: zoom,
              address: addr,
              center: new google.maps.LatLng(lat, lng),
              mapTypeId: google.maps.MapTypeId.ROADMAP
            },
            map;

        map = new google.maps.Map( this, mapOptions);
        maps.addMarker(map, mapOptions);
      });
    },

    init: function() {
      if( this.$el.length == 0 )
        return;

      this.loadScript();
      window.createMap = this.createMap;
    }
  };

  return maps.init();
};


$(document).ready(function(){

gmaps('.gmap');
$('.entry-post iframe, .entry-post object').parent().fitVids(); // Responsive video

/* ===================================================================
  #Service Slider
=================================================================== */
$('.service-slider').imagesLoaded(function(){
  $(this).carouFredSel({
    width: '100%',
    height: 'auto',
    prev: '#prev2',
    next: '#next2',
    auto: false,
    infinite: false,
    circular: false,
    responsive:true,
    scroll: {
      items: 1
    }
  });
});


/* ===================================================================
  #Team Slider
=================================================================== */
$('.team-slider').imagesLoaded(function(){
  $(this).carouFredSel({
    width: '100%',
    height: 'auto',
    prev: '#prev',
    next: '#next',
    auto: false,
    infinite: false,
    circular: false,
    swipe: {
      onTouch:true
    },
    items: {
    visible: {
      min: 1,
      max: 6
      }
    }
  });
});


/* ===================================================================
  #Testimony Slider
=================================================================== */
// $('.say-list').imagesLoaded(function(){
//   $(this).carouFredSel({
//     direction: "up",
//     auto:false,
//     circular: false,
//     infinite: false,
//     width:'100%',
//     items: {
//       visible: {
//         min: 3,
//         max: 3
//       },
//     },
//     pagination: '#pager'
//   });
// });

/* ===================================================================
  #Testimony Author Description
=================================================================== */
(function(){
  var $author_photo = $('.team-slider a'),
      $author_desc = $('.slider-desc li');

  // Show first description
  $('.team-slider li:first').addClass('selected');
  $author_desc.filter(":first").show();

  $author_photo.click(function(e){
    e.preventDefault();

    var $el = $(this),
        target = $el.attr('href');
    $author_desc.hide();
    $(target).fadeIn();
    $el.parent().addClass('selected').siblings().removeClass('selected');
  });
})();

/* ===================================================================
  #Contact Form
=================================================================== */
var contactForm = {
  $form: $('.contact form'),
  
  showNotif: function() {
	if( typeof clearNotif !== "undefined") {
	  clearTimeout(clearNotif);
	}
  
	var clearNotif = setTimeout(function(){
	  $('.alert alert-success').fadeOut();
	}, 5000);
    $('<div class="alert alert-success">Email Sent!</div>').prependTo(contactForm.$form);
  },

  validateEmail: function(email) {    
    var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return re.test(email);
  },

  bindEvent: function() {
    var self = this;
    this.$form.bind('submit', function(e){
      e.preventDefault();
      if( self.$form.validate().form() ) {
        self.sendContact();
      }
    });
  },

  validate: function() {
    var validate_data = {
      'name': { required: true },
      'email': { email: true },
      'comment': { required: true }
    }, 
    isValid = false,
    self = this;

    // Iterate each validate data
    $.each(validate_data, function(inputName){
      var $input = self.$form.find('[name="'+ inputName +'"]');
      
      // If data is required
      if( this.required ) {
        if( $input.val() == '' ) {
          isValid = false;
          $input.addClass('error');
        } else {
          isValid = true;
          $input.removeClass('error');
        }
      }

      // If data is email
      else if( this.email ) {
        if( self.validateEmail( $input.val() ) ) {
          isValid = true;
          $input.removeClass('error');
        } else {
          isValid = false;
          $input.addClass('error');
        }
      }
    });
    console.log(isValid);
    return isValid;
  },

  sendContact: function() {
    $.ajax({
      url: config.ajaxurl,
      type: 'post',
      data: contactForm.$form.serialize() + '&action=email',
      success: function(res) {
        if( res == 1 ) {
          contactForm.showNotif();
          contactForm.$form.validate().resetForm();
        }
      }
    });
  },

  init: function() {    
    this.bindEvent();
  }
};
contactForm.init();


/* ===================================================================
  #Blog List - Masonry
=================================================================== */
var $listMasonry = $('.list-blog');
$listMasonry.imagesLoaded(function(){
  $listMasonry.masonry({
    itemSelector: '.list-blog li',
     isAnimated: true
  });
});


/* ===================================================================
  #Collapsible Mobile Menu
=================================================================== */
$('.btn-navbar').click(function(e){
  e.preventDefault();
  var $el = $(this),
      $navCollapse = $el.next('.nav-collapse');

  // If collapsed
  if( $el.hasClass('collapsed') ) {
    $navCollapse.height( $navCollapse.children().outerHeight(true) );
    $el.removeClass('collapsed');
  } else {
    $navCollapse.height(0);
    $el.addClass('collapsed');
  }
});


/* ===================================================================
  Superfish
=================================================================== */
$('.top-nav ul:first').addClass('sf-menu').superfish({
  delay: 300,
  animation: { opacity: 'show' },
  speed: 'fast',
  dropShadows: false,
  onInit: function() {
    var $el = $(this);
    // Replace submenu indicator
    $el.find('.sf-sub-indicator').html('<i class="icon-caret-down"></i>');
    $el.find('ul .sf-sub-indicator').html('<i class="icon-caret-right"></i>');
  }
});


/* ===================================================================
  #Fancybox
=================================================================== */
function runFancybox() {
  if( /Android|webOS|iPhone|iPad|iPod|BlackBerry/i.test(navigator.userAgent) ) {
    $('.list-blog .popup').click(function(e){
      var $el = $(this),
          url = $el.data('url');
      window.location.href = url;
      console.log(url);
      e.preventDefault();
    });
  } else {
    $(".list-blog .popup, .list-blog .entry-image a").fancybox({
      'titlePosition'   : 'inside',
      'transitionIn'    : 'none',
      'transitionOut'   : 'none'
    });
  } 
}

runFancybox();

$('.portfolio-zoom').fancybox({
	showNavArrows: false
});

function portoFilter() {
  var $portfolio  = $('.work-slider');
  // Hover event
  $portfolio.find('.work-item').mouseenter(function(e){
    $(this).siblings().stop(true, true).fadeTo(500,0.5).addClass('blurred');
  }).mouseleave(function(e){
    $portfolio.find('.work-item').stop(true, true).delay(200).fadeTo(500,1).removeClass('blurred');
  });
};


/* ===================================================================
  #Load More Post
=================================================================== */
(function(){
  var nextpage  = 2,
      endPage   = false,
      container = $('.list-blog'),
      loader    = $('.reload a'),
      loaderAnim  = loader.find('.loading'),
      loaderMessage = loader.next('.message');

  // Bind click event to button trigger
  loader.click(function(e){
    var $el = $(this),
        action =  $el.attr('href').replace('#', ''),
        data_tax = $el.data('tax'),
        dataPaged = $el.data('paged'),
        targetContainer = $el.parent().prev(),
        tax;

    if( typeof data_tax !== 'undefined' && data_tax !== '' ) {
      tax = data_tax
    } else {
      tax = '';
    }
        
    e.preventDefault();
    loadmore( dataPaged, action, targetContainer, tax );
    $el.data('paged', dataPaged+=1);
  });

  function loadmore(page, action, targetContainer, tax) {
    $.ajax({
      url: config.ajaxurl,
      cache: true,
      type: 'post',
      data: {
        action: action,
        paged: page,
        term: tax
      },
      beforeSend: function() {
        // targetContainer.next().find('img').animate({opacity: 0})
        targetContainer.next().find('.btn').text('Loading...');
      },
      success: function(res) {
        if( res !== '' ) {
          // var $newElems = $(res).css({ opacity: 0 });
          var $newElems = $(res);
          // $newElems.css('opacity', 0);
          $newElems.appendTo(targetContainer);
          // ensure that images load before adding to masonry layout  
          $newElems.imagesLoaded(function(){
            // show elems when they're ready
            // $newElems.animate({ 'opacity': 1 });
            if( targetContainer.hasClass('list-blog') ) {
              targetContainer.masonry( 'appended', $newElems, true );
            }
            // targetContainer.next().find('img').animate({opacity: 1});
            targetContainer.next().find('.btn').text('More');
          });
          runFancybox();
        } else {
          targetContainer.next().find('.btn').hide();
        }
      }
    });
  };
})();


/* Fix Background Size on IE
------------------------------------------------------------------- */
// if( $.browser.msie ) {
//   $('.scrollblock').each(function(i){
//     var $block = $(this),
//         image = $block.css('background-image').replace('url(', '').replace(')', '');
//     if( image !== '' && image !== 'none' ) {
//       $block.attr('id', 'scrollblock-' + i);
//       $('#scrollblock' + i).anystretch(image)
//     }
//   });
// }


function filterPath(string) {
  return string
    .replace(/^\//,'')
    .replace(/(index|default).[a-zA-Z]{3,4}$/,'')
    .replace(/\/$/,'');
 }
  var locationPath = filterPath(location.pathname);
  var scrollElem = scrollableElement('html', 'body');
 
  $('.top-nav .menu-item a[href*=#]').each(function() {
    var thisPath = filterPath(this.pathname) || locationPath;
    if (  locationPath == thisPath
    && (location.hostname == this.hostname || !this.hostname)
    && this.hash.replace(/#/,'') ) {
      var $target = $(this.hash), target = this.hash;
      if (target) {
        var targetOffset = $target.offset().top;
        $(this).click(function(event) {
          event.preventDefault();
          $(scrollElem).animate({scrollTop: targetOffset}, 400, function() {
            location.hash = target;
          });
        });
      }
    }
  });
 
  // use the first element that is "scrollable"
  function scrollableElement(els) {
    for (var i = 0, argLength = arguments.length; i <argLength; i++) {
      var el = arguments[i],
          $scrollElement = $(el);
      if ($scrollElement.scrollTop()> 0) {
        return el;
      } else {
        $scrollElement.scrollTop(1);
        var isScrollable = $scrollElement.scrollTop()> 0;
        $scrollElement.scrollTop(0);
        if (isScrollable) {
          return el;
        }
      }
    }
    return [];
  }

});
})(jQuery);