<?php 
$colabs_options = get_option( 'colabs_options' );

/*-----------------------------------------------------------------------------------

TABLE OF CONTENTS

1. Add specific IE hacks to HEAD
2. CoLabs Conditinals
3. Post Meta
4. Activate shortcode compatibility in our new custom areas
5. Read More Button
6. Colabs Post Image - colabs_post_image
7. Colabs Post Related - colabs_post_related

-----------------------------------------------------------------------------------*/


add_action('wp_head','colabs_IE_head');					// Add specific IE styling/hacks to HEAD
add_filter( 'body_class','colabs_layout_body_class', 10 );

remove_action('wp_head', 'colabsthemes_wp_head');
add_action('colabs_head', 'colabsthemes_wp_head');


add_filter( 'post_class','colabs_layout_post_class', 10 );					// Add layout to post_class output

/*-----------------------------------------------------------------------------------*/
/* 1. Add specific IE hacks to HEAD */
/*-----------------------------------------------------------------------------------*/
if (!function_exists('colabs_IE_head')) {
	function colabs_IE_head() {
?>
<!--[if IE 6]>
<script type="text/javascript" src="<?php  get_template_directory_uri(); ?>/includes/js/pngfix.js"></script>
<![endif]-->
<!--[if IE 7]>
<link href="<?php get_template_directory_uri(); ?>/includes/css/ie7.css" rel="stylesheet" type="text/css" />
<![endif]-->
<?php
	}
}


/*-----------------------------------------------------------------------------------*/
/* 4. Activate shortcode compatibility in our new custom areas. */
/*-----------------------------------------------------------------------------------*/  
/**
 * Activate shortcode compatibility in our new custom areas.
 *
 * @package CoLabsFramework
 * @subpackage Filters
 */
 	$sections = array( 'colabs_filter_post_meta', 'colabs_post_inside_after_default', 'colabs_post_more', 'colabs_footer_left', 'colabs_footer_right' );
 
 	foreach ( $sections as $s ) { add_filter( $s, 'do_shortcode', 20 ); }
    


/*-----------------------------------------------------------------------------------*/
/* 7. Colabs Post Related - colabs_post_related. */
/*-----------------------------------------------------------------------------------*/
if (!function_exists('colabs_post_related')) {
	function colabs_post_related() {
	   
    if( is_single() ){
    ?>
    <div class="related-posts">
        <h3><?php _e('Related Posts','colabsthemes'); ?></h3>
        <?php echo apply_filters( 'colabs_filter_post_meta', '[related_posts]' ); ?>
    </div>    
    <?php }
    }
}


/*-----------------------------------------------------------------------------------*/
/* 8. Add layout to post_class output */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'colabs_layout_post_class' ) ) {
	function colabs_layout_post_class( $classes ) {
	
		$layout = '';
		// Set main layout
        
        if( is_year() ) $layout = "date_year";
        
		if( is_month() ) $layout = "date_month";
        
        if( is_day() ) $layout = "date_day";
		
			
		// Add classes to post_class() output
        $classes[] = $layout;
        
        return apply_filters('colabs_layout_post_class', $classes);
	}
}

/*-----------------------------------------------------------------------------------*/
/* Add layout to body_class output */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'colabs_layout_body_class' ) ) {
	function colabs_layout_body_class( $classes ) {
	
		$layout = '';
		// Set main layout
		if ( is_singular() ) {
			global $post;
			$layout = get_post_meta($post->ID, 'layout', true); }
		
        
        //set $colabs_option
        if ( '' != $layout ) {
			global $colabs_options;
            $colabs_options['colabs_layout'] = $layout; 
		} else {
            $layout = get_option( 'colabs_layout_settings' );
			if ( '' == $layout ) $layout = "two-col-left";
        }
                		
		// Add classes to body_class() output 
		$classes[] = $layout;

        
		return apply_filters('colabs_layout_body_class', $classes);
	}
}

/*-----------------------------------------------------------------------------------*/
/* CoLabs Advertisement - colabs_ad_gen */
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'colabs_ad_gen' ) ) {
	function colabs_ad_gen() { 
	   
    global $colabs_options;
    global $post;
    
    //default
    $colabs_ad_single = $colabs_options['colabs_ad_single'];
    $colabs_ad_single_adsense = $colabs_options['colabs_ad_single_adsense'];
    $colabs_ad_single_image = $colabs_options['colabs_ad_single_image'];
    $colabs_ad_single_url = $colabs_options['colabs_ad_single_url'];
    $width = 728;
    $height = 90;
    
    //Single Custom Ad
    $colabs_ad_single_custom = get_post_meta($post->ID, 'colabs_ad_single', true); //none, general_ad, custom_ad
    
    if( 'custom_ad' == $colabs_ad_single_custom ){
        $colabs_ad_single = 'true';
        $colabs_ad_single_adsense = get_post_meta($post->ID, 'colabs_ad_single_adsense', true);
        $colabs_ad_single_image = get_post_meta($post->ID, 'colabs_ad_single_image', true);
        $colabs_ad_single_url = get_post_meta($post->ID, 'colabs_ad_single_url', true);
        }
    
        if ( 'true' == $colabs_ad_single && 'none' != $colabs_ad_single_custom && ( '' != $colabs_ad_single_adsense || '' != $colabs_ad_single_image ) ) { ?>
	    <div id="singlead">
            <?php if ($colabs_ad_single_adsense <> "") { echo stripslashes($colabs_ad_single_adsense);  } else { ?>
                <a href="<?php echo $colabs_ad_single_url; ?>"><img src="<?php echo $colabs_ad_single_image; ?>" width="<?php echo $width; ?>" height="<?php echo $height; ?>" alt="advert" /></a>
            <?php } ?>		   	
        </div><!-- /#topad -->
        <?php }
	}
}
/*-----------------------------------------------------------------------------------*/
/* END */
/*-----------------------------------------------------------------------------------*/
?>