<?php
add_action('init', 'portfolio_register');
add_action('init', 'testimonial_register');

if ( ! function_exists( 'portfolio_register' ) ) {
	function portfolio_register() {
		$args = array(
			'description' => 'Portfolio Post Type',
			'show_ui' => true,
			'menu_position' => 4,
			'labels' => array(
				'name'=> 'Portfolios',
				'singular_name' => 'Portfolio',
				'add_new' => 'Add New Portfolio',
				'add_new_item' => 'Add New Portfolio',
				'edit' => 'Edit Portfolio',
				'edit_item' => 'Edit Portfolio',
				'new-item' => 'New Portfolio',
				'all_items' => 'All Portfolios',
				'view_item' => 'View Portfolio',
				'search_items' => 'Search Portfolios',
				'not_found' => 'No Portfolio Found',
				'not_found_in_trash' => 'No Portfolio Found in Trash',
				'parent' => 'Parent Portfolio'
			),
			'public' => true,
			'capability_type' => 'post',
			'hierarchical' => false,
			'publicly_queryable' => true,
			'query_var' => true,
			'rewrite' => array( 'slug' => 'portfolio-item'),
			'has_archive' => true, 
			'taxonomies' => array( 'portfolio-category' ), 
			'supports' => array('title', 'editor','thumbnail', 'author', 'excerpt')
		);

		register_post_type( 'portfolio' , $args );
		
		register_taxonomy('portfolio-category',
				array ( 'portfolio' ),
				array (
				'labels' => array (
						'name' => 'Portfolio Category',
						'singular_name' => 'Portfolio Category',
						'search_items' => 'Search Portfolio Category',
						'popular_items' => 'Popular Portfolio Category',
						'all_items' => 'All Portfolio Category',
						'parent_item' => 'Parent Portfolio Category',
						'parent_item_colon' => 'Parent Portfolio Category:',
						'edit_item' => 'Edit Portfolio Category',
						'update_item' => 'Update Portfolio Category',
						'add_new_item' => 'Add New Portfolio Category',
						'new_item_name' => 'New Portfolio Category',
						),
						'hierarchical' =>true,
						'show_ui' => true,
						'show_tagcloud' => true,
						'query_var' => true,
						'rewrite' => array( 'slug' => 'portfolio-category' ),
				));
		
		
		flush_rewrite_rules();
		
	}
}

add_filter("manage_edit-portfolio_columns", "portfolio_edit_columns");   
  
function portfolio_edit_columns($columns){  
        $columns = array(  
            "cb" => "<input type=\"checkbox\" />",  
			"photo" => __("Image","colabsthemes"),
            "title" => __("Portfolio","colabsthemes"),  
            "category" => __("Portfolio Category","colabsthemes"),  
            "date" => __("Date","colabsthemes"),
        );  
  
        return $columns;  
}  

add_action("manage_portfolio_posts_custom_column",  "portfolio_custom_columns"); 

  
function portfolio_custom_columns($column){  
        global $post;  
        switch ($column)  
        {     
            case "category":  
                echo get_the_term_list($post->ID, 'portfolio-category', '', ', ','');  
                break; 
			case "photo":
				if(has_post_thumbnail()) the_post_thumbnail(array(50,50));
				break;	
        }  
}  

// CREATE SORT WITH CUSTOM TAXONOMIES
add_filter( 'manage_edit-portfolio_sortable_columns', 'portfolio_sortable_columns' );

function portfolio_sortable_columns( $columns ) {

	$columns['portfolio-category'] = 'portfolio-category';

	return $columns;
}
// CREATE FILTERS WITH CUSTOM TAXONOMIES

if ( isset($_GET['post_type']) ) {
	$post_type = $_GET['post_type'];
}
else {
	$post_type = '';
}

if ( 'portfolio' == $post_type ) {
	add_action( 'restrict_manage_posts','portfolio_category_filter_list' );
	add_filter('posts_where', 'colabs_portfolio_posts_where');
}



function portfolio_category_filter_list() {
  $screen = get_current_screen();
  global $wp_query;
  if ( 'portfolio' == $screen->post_type ) {
		wp_dropdown_categories(array(
						'show_option_all' => 'Show All Portfolio Types',
						'taxonomy' => 'portfolio-category',
						'name' => 'portfolio-category',
						'orderby' => 'name',
						'selected' =>( isset( $wp_query->query['portfolio-category'] ) ?
						$wp_query->query['portfolio-category'] : '' ),
					  'hierarchical' => false,
					  'depth' => 3,
					  'show_count' => false,
					  'hide_empty' => true,
			));
		
	}
}

// Custom Query to filter edit grid
function colabs_portfolio_posts_where($where) {
    if( is_admin() ) {
        global $wpdb;
        if (isset($_GET['type_names'])) { $type_ID = $_GET['type_names'];  } else { $type_ID = '';  }
		if ( ($location_ID > 0) || ($type_ID > 0) || ($feature_ID > 0) ) {

			$type_tax_names =  &get_term( $type_ID, 'portfolio-category' );
			$string_post_ids = '';
 		
			//portfolio types
			if ($type_ID > 0) {
				$type_tax_name = $type_tax_names->slug;
				$type_myposts = get_posts('nopaging=true&post_type=portfolio&portfolio-category='.$type_tax_name);
				foreach($type_myposts as $post) {
					$string_post_ids .= $post->ID.',';
				}
			}
			
 			$string_post_ids = chop($string_post_ids,',');
   			$where .= "AND ID IN (" . $string_post_ids . ")";
		}
    }
    return $where;
}

add_filter( 'parse_query','perform_filtering' );

function perform_filtering( $query )
 {
    $qv = &$query->query_vars;
    if (isset($qv['portfolio-category']) && ( $qv['portfolio-category'] ) && is_numeric( $qv['portfolio-category'] ) ) {
      $term = get_term_by( 'id', $qv['portfolio-category'], 'portfolio-category' ); 
			$qv['portfolio-category'] = $term->slug;
		}
	
}	  

if ( ! function_exists( 'testimonial_register' ) ) {
function testimonial_register() {
	$args = array(
		'description' => 'Testimonial Post Type',
		'show_ui' => true,
		'menu_position' => 4,
		'labels' => array(
			'name'=> 'Testimonials',
			'singular_name' => 'Testimonials',
			'add_new' => 'Add New Testimonial',
			'add_new_item' => 'Add New Testimonial',
			'edit' => 'Edit Testimonial',
			'edit_item' => 'Edit Testimonial',
			'new-item' => 'New Testimonial',
			'all_items' => 'All Testimonials',
			'view_item' => null,
			'search_items' => 'Search Testimonials',
			'not_found' => 'No Testimonial Found',
			'not_found_in_trash' => 'No Testimonial Found in Trash',
			'parent' => 'Parent Testimonial'
		),		
			'public' => true,
			'capability_type' => 'post',
			'hierarchical' => false,
			'publicly_queryable' => true,
			'query_var' => false,
			'rewrite' => array( 'slug' => 'testimonial'),
			'has_archive' => false, 
			'exclude_from_search' => true,
		'supports' => array('title', 'editor','thumbnail')
	);

	register_post_type( 'testimonial' , $args );
    
    
    flush_rewrite_rules();
    
}
} 


add_filter("manage_edit-testimonial_columns", "testimonial_edit_columns");     

function testimonial_edit_columns($columns){  
        $columns = array(  
            "cb" => "<input type=\"checkbox\" />",  
            "title" => __("Testimonial","colabsthemes"),   
            "name" => __("Name","colabsthemes"),  
            "company" => __("Company","colabsthemes"),  
            "link" => __("Link","colabsthemes"),  
            "date" =>__("Date","colabsthemes"),
        );  
  
        return $columns;  
}

add_action("manage_posts_custom_column",  "testimonial_custom_columns");  
function testimonial_custom_columns($column){  
        global $post;  
        $custom = get_post_custom();  
        switch ($column){  
            case "name":  
                echo $custom["colabs_user_name"][0];  
                break; 
            case "company":  
                echo $custom["colabs_user_company"][0]; 
                break;   
            case "link":  
                echo $custom["colabs_user_url"][0];  
                break;  
        }  
}
?>